@@ -1,5 +1,9 @@
 import typing as t
 
+from acb import register_pkg
+
+register_pkg("crackerjack")
+
 from .api import (
     CrackerjackAPI,
     PublishResult,
