@@ -56,6 +56,9 @@ class RefurbSettings(ToolAdapterSettings):
     enable_checks: list[str] = Field(default_factory=list)
     python_version: str | None = None  # e.g., "3.13"
     explain: bool = False  # Show detailed explanations
+    timeout_seconds: int = (
+        660  # 11 minutes to allow for comprehensive refactoring analysis
+    )
 
 
 class RefurbAdapter(BaseToolAdapter):
@@ -211,69 +214,147 @@ class RefurbAdapter(BaseToolAdapter):
             if "[FURB" not in line:
                 continue
 
-            try:
-                # Split on first colon to get file path
-                if ":" not in line:
-                    continue
-
-                parts = line.split(":", maxsplit=3)
-                if len(parts) < 3:
-                    continue
-
-                file_path = Path(parts[0].strip())
-                line_number = int(parts[1].strip())
-
-                # Parse column and message
-                remaining = parts[2].strip()
-                column_number = None
-                message_part = remaining
-
-                # Try to extract column number
-                if " " in remaining:
-                    first_part = remaining.split()[0]
-                    if first_part.isdigit():
-                        column_number = int(first_part)
-                        message_part = remaining[len(first_part) :].strip()
-
-                # Extract code and message
-                if "[" in message_part and "]" in message_part:
-                    code_start = message_part.index("[")
-                    code_end = message_part.index("]")
-                    code = message_part[code_start + 1 : code_end]
-                    message = message_part[code_end + 1 :].strip()
-                    if message.startswith(":"):
-                        message = message[1:].strip()
-                else:
-                    code = None
-                    message = message_part
-
-                issue = ToolIssue(
-                    file_path=file_path,
-                    line_number=line_number,
-                    column_number=column_number,
-                    message=message,
-                    code=code,
-                    severity="warning",  # Refurb suggestions are warnings
-                )
+            issue = self._parse_refurb_line(line)
+            if issue:
                 issues.append(issue)
 
-            except (ValueError, IndexError):
-                continue
-
         logger.info(
             "Parsed Refurb output",
             extra={
                 "total_issues": len(issues),
-                "files_affected": len(set(str(i.file_path) for i in issues)),
-                "unique_codes": len(set(i.code for i in issues if i.code)),
+                "files_affected": len({str(i.file_path) for i in issues}),
+                "unique_codes": len({i.code for i in issues if i.code}),
             },
         )
         return issues
 
+    def _parse_refurb_line(self, line: str) -> ToolIssue | None:
+        """Parse a single Refurb output line.
+
+        Args:
+            line: Line of Refurb output
+
+        Returns:
+            ToolIssue if parsing successful, None otherwise
+        """
+        try:
+            if ":" not in line:
+                return None
+
+            parts = line.split(":", maxsplit=3)
+            if len(parts) < 3:
+                return None
+
+            file_path = Path(parts[0].strip())
+            line_number = int(parts[1].strip())
+
+            # Parse column and message
+            remaining = parts[2].strip()
+            column_number = self._extract_column_number(remaining)
+            message_part = self._extract_message_part(remaining, column_number)
+
+            # Extract code and message
+            code, message = self._extract_code_and_message(message_part)
+
+            return ToolIssue(
+                file_path=file_path,
+                line_number=line_number,
+                column_number=column_number,
+                message=message,
+                code=code,
+                severity="warning",  # Refurb suggestions are warnings
+            )
+
+        except (ValueError, IndexError):
+            return None
+
+    def _extract_column_number(self, remaining: str) -> int | None:
+        """Extract column number from remaining string.
+
+        Args:
+            remaining: Remaining part after file and line
+
+        Returns:
+            Column number if found, None otherwise
+        """
+        if " " in remaining:
+            first_part = remaining.split()[0]
+            if first_part.isdigit():
+                return int(first_part)
+        return None
+
+    def _extract_message_part(self, remaining: str, column_number: int | None) -> str:
+        """Extract message part from remaining string.
+
+        Args:
+            remaining: Remaining part after file and line
+            column_number: Extracted column number if any
+
+        Returns:
+            Message part of the line
+        """
+        if column_number is not None and " " in remaining:
+            first_part = remaining.split()[0]
+            return remaining[len(first_part) :].strip()
+        return remaining
+
+    def _extract_code_and_message(self, message_part: str) -> tuple[str | None, str]:
+        """Extract code and message from message part.
+
+        Args:
+            message_part: Part containing code and message
+
+        Returns:
+            Tuple of (code, message)
+        """
+        if "[" in message_part and "]" in message_part:
+            code_start = message_part.index("[")
+            code_end = message_part.index("]")
+            code = message_part[code_start + 1 : code_end]
+            message = message_part[code_end + 1 :].strip()
+            if message.startswith(":"):
+                message = message[1:].strip()
+            return code, message
+        return None, message_part
+
     def _get_check_type(self) -> QACheckType:
         """Return refactor check type."""
         return QACheckType.REFACTOR
 
+    def _detect_package_directory(self) -> str:
+        """Detect the package directory name from pyproject.toml.
+
+        Returns:
+            Package directory name (e.g., 'crackerjack', 'session_mgmt_mcp')
+        """
+        from contextlib import suppress
+
+        current_dir = Path.cwd()
+
+        # Try to read package name from pyproject.toml
+        pyproject_path = current_dir / "pyproject.toml"
+        if pyproject_path.exists():
+            with suppress(Exception):
+                import tomllib
+
+                with pyproject_path.open("rb") as f:
+                    data = tomllib.load(f)
+
+                if "project" in data and "name" in data["project"]:
+                    # Convert package name to directory name (replace - with _)
+                    package_name = str(data["project"]["name"]).replace("-", "_")
+
+                    # Verify directory exists
+                    if (current_dir / package_name).exists():
+                        return package_name
+
+        # Fallback to directory name if package dir exists
+        if (current_dir / current_dir.name).exists():
+            return current_dir.name
+
+        # Default fallback
+        return "src"
+
     def get_default_config(self) -> QACheckConfig:
         """Get default configuration for Refurb adapter.
 
@@ -282,12 +363,17 @@ class RefurbAdapter(BaseToolAdapter):
         """
         from crackerjack.models.qa_config import QACheckConfig
 
+        # Dynamically detect package directory
+        package_dir = self._detect_package_directory()
+
         return QACheckConfig(
             check_id=MODULE_ID,
             check_name=self.adapter_name,
             check_type=QACheckType.REFACTOR,
             enabled=True,
-            file_patterns=["crackerjack/**/*.py"],  # Only target package directory
+            file_patterns=[
+                f"{package_dir}/**/*.py"
+            ],  # Dynamically detected package directory
             exclude_patterns=[
                 "**/test_*.py",
                 "**/tests/**",
@@ -303,7 +389,7 @@ class RefurbAdapter(BaseToolAdapter):
                 "**/htmlcov/**",
                 "**/.coverage*",
             ],
-            timeout_seconds=90,
+            timeout_seconds=240,
             parallel_safe=True,
             stage="comprehensive",  # Refactoring suggestions in comprehensive stage
             settings={
