@@ -61,12 +61,9 @@ class EnhancedCacheHandlers:
             pre_clear_stats = self.cache.get_cache_stats()
 
             # Clear memory caches and get cleanup stats
+            # Note: cleanup_all() already handles all cache types (memory + disk)
             cleanup_results = self.cache.cleanup_all()
 
-            # Clear disk cache completely
-            if self.cache.enable_disk_cache and self.cache.cache_dir:
-                self.cache.disk_cache.clear()
-
             # Calculate total items cleared
             total_cleared = sum(cleanup_results.values())
 
