@@ -78,6 +78,7 @@ class Options(BaseModel):
     bump: BumpOption | None = None
     verbose: bool = False
     debug: bool = False
+    ai_debug: bool = False  # Enable verbose debugging for AI auto-fixing mode
     benchmark: bool = False
     test_workers: int = 0
     test_timeout: int = 0
@@ -91,6 +92,7 @@ class Options(BaseModel):
     fast_iteration: bool = False  # Phase 10.2.4: Skip comprehensive hooks
     tool: str | None = None  # Phase 10.2.4: Run only specific tool
     changed_only: bool = False  # Phase 10.2.4: Run on changed files only
+    all_files: bool = False  # Run hooks on all files (not just changed)
     async_mode: bool = False
     experimental_hooks: bool = False
     enable_pyrefly: bool = False
@@ -380,8 +382,12 @@ CLI_OPTIONS = {
         0,
         "--test-workers",
         help=(
-            "Number of parallel workers for running tests "
-            "(0 = auto-detect, 1 = disable parallelization)."
+            "Number of parallel workers for running tests. "
+            "0 = auto-detect via pytest-xdist (default), "
+            "1 = sequential execution, "
+            ">1 = explicit worker count, "
+            "<0 = fractional (e.g., -2 = half of CPU cores). "
+            "Set CRACKERJACK_DISABLE_AUTO_WORKERS=1 to force sequential."
         ),
     ),
     "test_timeout": typer.Option(
@@ -426,6 +432,11 @@ CLI_OPTIONS = {
         "--changed-only",
         help="Run quality checks only on files changed in git.",
     ),
+    "all_files": typer.Option(
+        False,
+        "--all-files",
+        help="Run hooks on all files (not just changed files). Useful for CI/CD or after dependency updates.",
+    ),
     "create_pr": typer.Option(
         False,
         "-r",
@@ -1010,83 +1021,84 @@ def create_options(
     skip_hooks: bool,
     fast: bool,
     comp: bool,
-    fast_iteration: bool,
-    tool: str | None,
-    changed_only: bool,
-    create_pr: bool,
-    async_mode: bool,
-    experimental_hooks: bool,
-    enable_pyrefly: bool,
-    enable_ty: bool,
-    start_zuban_lsp: bool,
-    stop_zuban_lsp: bool,
-    restart_zuban_lsp: bool,
-    no_zuban_lsp: bool,
-    zuban_lsp_port: int,
-    zuban_lsp_mode: str,
-    zuban_lsp_timeout: int,
-    enable_lsp_hooks: bool,
-    no_git_tags: bool,
-    skip_version_check: bool,
-    orchestrated: bool,
-    orchestration_strategy: str,
-    orchestration_progress: str,
-    orchestration_ai_mode: str,
-    dev: bool,
-    dashboard: bool,
-    unified_dashboard: bool,
-    unified_dashboard_port: int | None,
-    max_iterations: int,
-    coverage_status: bool,
-    coverage_goal: float | None,
-    no_coverage_ratchet: bool,
-    boost_coverage: bool,
-    disable_global_locks: bool,
-    global_lock_timeout: int,
-    global_lock_cleanup: bool,
-    global_lock_dir: str | None,
-    quick: bool,
-    thorough: bool,
-    clear_cache: bool,
-    cache_stats: bool,
-    generate_docs: bool,
-    docs_format: str,
-    validate_docs: bool,
-    generate_changelog: bool,
-    changelog_version: str | None,
-    changelog_since: str | None,
-    changelog_dry_run: bool,
-    auto_version: bool,
-    version_since: str | None,
-    accept_version: bool,
-    smart_commit: bool,
-    heatmap: bool,
-    heatmap_type: str,
-    heatmap_output: str | None,
-    anomaly_detection: bool,
-    anomaly_sensitivity: float,
-    anomaly_report: str | None,
-    predictive_analytics: bool,
-    prediction_periods: int,
-    analytics_dashboard: str | None,
+    fast_iteration: bool = False,
+    tool: str | None = None,
+    changed_only: bool = False,
+    all_files: bool = False,
+    create_pr: bool = False,
+    async_mode: bool = False,
+    experimental_hooks: bool = False,
+    enable_pyrefly: bool = False,
+    enable_ty: bool = False,
+    start_zuban_lsp: bool = False,
+    stop_zuban_lsp: bool = False,
+    restart_zuban_lsp: bool = False,
+    no_zuban_lsp: bool = False,
+    zuban_lsp_port: int = 8677,
+    zuban_lsp_mode: str = "tcp",
+    zuban_lsp_timeout: int = 30,
+    enable_lsp_hooks: bool = False,
+    no_git_tags: bool = False,
+    skip_version_check: bool = False,
+    orchestrated: bool = False,
+    orchestration_strategy: str = "adaptive",
+    orchestration_progress: str = "granular",
+    orchestration_ai_mode: str = "single-agent",
+    dev: bool = False,
+    dashboard: bool = False,
+    unified_dashboard: bool = False,
+    unified_dashboard_port: int | None = None,
+    max_iterations: int = 10,
+    coverage_status: bool = False,
+    coverage_goal: float | None = None,
+    no_coverage_ratchet: bool = False,
+    boost_coverage: bool = True,
+    disable_global_locks: bool = False,
+    global_lock_timeout: int = 600,
+    global_lock_cleanup: bool = True,
+    global_lock_dir: str | None = None,
+    quick: bool = False,
+    thorough: bool = False,
+    clear_cache: bool = False,
+    cache_stats: bool = False,
+    generate_docs: bool = False,
+    docs_format: str = "markdown",
+    validate_docs: bool = False,
+    generate_changelog: bool = False,
+    changelog_version: str | None = None,
+    changelog_since: str | None = None,
+    changelog_dry_run: bool = False,
+    auto_version: bool = False,
+    version_since: str | None = None,
+    accept_version: bool = False,
+    smart_commit: bool = True,
+    heatmap: bool = False,
+    heatmap_type: str = "error_frequency",
+    heatmap_output: str | None = None,
+    anomaly_detection: bool = False,
+    anomaly_sensitivity: float = 2.0,
+    anomaly_report: str | None = None,
+    predictive_analytics: bool = False,
+    prediction_periods: int = 10,
+    analytics_dashboard: str | None = None,
     # Advanced features
-    advanced_optimizer: bool,
-    advanced_profile: str | None,
-    advanced_report: str | None,
-    mkdocs_integration: bool,
-    mkdocs_serve: bool,
-    mkdocs_theme: str,
-    mkdocs_output: str | None,
-    contextual_ai: bool,
-    ai_recommendations: int,
-    ai_help_query: str | None,
-    check_config_updates: bool,
-    apply_config_updates: bool,
-    diff_config: str | None,
-    config_interactive: bool,
-    refresh_cache: bool,
-    use_acb_workflows: bool,
-    use_legacy_orchestrator: bool,
+    advanced_optimizer: bool = False,
+    advanced_profile: str | None = None,
+    advanced_report: str | None = None,
+    mkdocs_integration: bool = False,
+    mkdocs_serve: bool = False,
+    mkdocs_theme: str = "material",
+    mkdocs_output: str | None = None,
+    contextual_ai: bool = False,
+    ai_recommendations: int = 5,
+    ai_help_query: str | None = None,
+    check_config_updates: bool = False,
+    apply_config_updates: bool = False,
+    diff_config: str | None = None,
+    config_interactive: bool = False,
+    refresh_cache: bool = False,
+    use_acb_workflows: bool = True,
+    use_legacy_orchestrator: bool = False,
     # New semantic parameters
     strip_code: bool | None = None,
     run_tests: bool = False,
@@ -1116,6 +1128,7 @@ def create_options(
         fast_iteration=fast_iteration,
         tool=tool,
         changed_only=changed_only,
+        all_files=all_files,
         create_pr=create_pr,
         async_mode=async_mode,
         experimental_hooks=experimental_hooks,
