@@ -167,6 +167,32 @@ FAST_HOOKS = [
         use_precommit_legacy=False,  # Phase 8.4: Direct invocation
         accepts_file_paths=True,  # Phase 10.4.4: File-level validator
     ),
+    HookDefinition(
+        name="check-json",
+        command=[],
+        timeout=30,  # UV init (~10s) + tool execution (P95=~0.5s) + safety margin
+        security_level=SecurityLevel.MEDIUM,
+        use_precommit_legacy=False,  # Phase 8.4: Direct invocation
+        accepts_file_paths=True,  # Phase 10.4.4: File-level validator
+    ),
+    HookDefinition(
+        name="check-ast",
+        command=[],
+        timeout=30,  # UV init (~10s) + tool execution (P95=~0.2s) + safety margin
+        security_level=SecurityLevel.HIGH,
+        use_precommit_legacy=False,  # Phase 8.4: Direct invocation
+        accepts_file_paths=True,  # Phase 10.4.4: File-level validator
+    ),
+    HookDefinition(
+        name="format-json",
+        command=[],
+        is_formatting=True,
+        timeout=45,  # UV init (~10s) + tool execution + formatting overhead
+        retry_on_failure=True,
+        security_level=SecurityLevel.LOW,
+        use_precommit_legacy=False,  # Phase 8.4: Direct invocation
+        accepts_file_paths=True,  # Phase 10.4.4: File-level formatter
+    ),
     HookDefinition(
         name="check-added-large-files",
         command=[],
@@ -213,7 +239,7 @@ FAST_HOOKS = [
         name="mdformat",
         command=[],
         is_formatting=True,
-        timeout=45,  # UV init (~10s) + tool execution + markdown processing overhead
+        timeout=120,  # 266 markdown files + mdformat-ruff plugin overhead (~0.45s per file average)
         retry_on_failure=True,
         security_level=SecurityLevel.LOW,
         use_precommit_legacy=False,  # Phase 8.4: Direct invocation
@@ -225,22 +251,33 @@ COMPREHENSIVE_HOOKS = [
     HookDefinition(
         name="zuban",
         command=[],
-        timeout=40,  # UV init (~10s) + tool execution (P95=10.97s) + safety margin
+        timeout=80,  # UV init (~10s) + tool execution (P95=10.97s) + increased safety margin
         stage=HookStage.COMPREHENSIVE,
         manual_stage=True,
-        security_level=SecurityLevel.CRITICAL,
+        security_level=SecurityLevel.HIGH,  # Changed from CRITICAL to HIGH to allow other hooks to run
         use_precommit_legacy=False,  # Phase 8.4: Direct invocation
     ),
     HookDefinition(
-        name="bandit",
+        name="semgrep",
         command=[],
-        timeout=90,  # Allow more time for repo-wide security scan
+        timeout=240,  # 4 minutes - most scans complete in <1 min (observed: 9-10s)
         stage=HookStage.COMPREHENSIVE,
         manual_stage=True,
         security_level=SecurityLevel.CRITICAL,
         use_precommit_legacy=False,  # Phase 8.4: Direct invocation
-        accepts_file_paths=True,  # Phase 10.4.4: File-level security scanner
+        accepts_file_paths=True,  # Phase 10.4.4: File-level SAST scanner
     ),
+    # NOTE: Bandit replaced with Semgrep (using uvx for Python 3.13 isolation)
+    # HookDefinition(
+    #     name="bandit",
+    #     command=[],
+    #     timeout=180,  # 3 minutes for SAST scanning
+    #     stage=HookStage.COMPREHENSIVE,
+    #     manual_stage=True,
+    #     security_level=SecurityLevel.CRITICAL,
+    #     use_precommit_legacy=False,  # Phase 8.4: Direct invocation
+    #     accepts_file_paths=True,  # Phase 10.4.4: File-level SAST scanner
+    # ),
     HookDefinition(
         name="gitleaks",
         command=[],
@@ -258,15 +295,17 @@ COMPREHENSIVE_HOOKS = [
         manual_stage=True,
         security_level=SecurityLevel.MEDIUM,
         use_precommit_legacy=False,  # Phase 8.4: Direct invocation
+        accepts_file_paths=True,  # Phase 10.5: Incremental execution on changed files
     ),
     HookDefinition(
         name="refurb",
         command=[],
-        timeout=600,  # Increased to 600s to accommodate large codebase analysis
+        timeout=240,  # 4 minutes - matches adapter default
         stage=HookStage.COMPREHENSIVE,
         manual_stage=True,
         security_level=SecurityLevel.MEDIUM,
         use_precommit_legacy=False,  # Phase 8.4: Direct invocation
+        accepts_file_paths=True,  # Phase 10.5: Incremental execution on changed files (240s -> ~10s)
     ),
     HookDefinition(
         name="creosote",
@@ -285,6 +324,17 @@ COMPREHENSIVE_HOOKS = [
         manual_stage=True,
         security_level=SecurityLevel.MEDIUM,
         use_precommit_legacy=False,  # Phase 8.4: Direct invocation
+        accepts_file_paths=True,  # Phase 10.5: Incremental execution on changed files
+    ),
+    HookDefinition(
+        name="check-jsonschema",
+        command=[],
+        timeout=60,  # UV init (~10s) + schema validation overhead
+        stage=HookStage.COMPREHENSIVE,
+        manual_stage=True,
+        security_level=SecurityLevel.HIGH,
+        use_precommit_legacy=False,  # Phase 8.4: Direct invocation
+        accepts_file_paths=True,  # Phase 10.4.4: File-level schema validator
     ),
 ]
 
