@@ -46,8 +46,9 @@ def _detect_package_name_cached(pkg_path_str: str) -> str:
             if item.name not in {"tests", "docs", ".venv", "venv", "build", "dist"}:
                 return item.name
 
-    # Fallback: use 'crackerjack' for backward compatibility
-    return "crackerjack"
+    # Method 3: Use the directory name as the package name
+    # Convert hyphens to underscores to match Python package naming conventions
+    return pkg_path.name.replace("-", "_")
 
 
 def _build_tool_commands(package_name: str) -> dict[str, list[str]]:
@@ -76,7 +77,7 @@ def _build_tool_commands(package_name: str) -> dict[str, list[str]]:
             "skylos",
             "--exclude-folder",
             "tests",
-            ".",
+            f"./{package_name}",
         ],
         "zuban": [
             "uv",
@@ -84,7 +85,8 @@ def _build_tool_commands(package_name: str) -> dict[str, list[str]]:
             "zuban",
             "check",
             "--config-file",
-            "mypy.ini",
+            "mypy.ini",  # Required: zuban v0.2.2 can't parse [tool.mypy] from pyproject.toml
+            "--no-error-summary",  # Suppress summary line (e.g., "Found N errors") to keep issue output clean
             f"./{package_name}",
         ],
         # ========================================================================
@@ -106,6 +108,16 @@ def _build_tool_commands(package_name: str) -> dict[str, list[str]]:
         ],
         "check-yaml": ["uv", "run", "python", "-m", "crackerjack.tools.check_yaml"],
         "check-toml": ["uv", "run", "python", "-m", "crackerjack.tools.check_toml"],
+        "check-json": ["uv", "run", "python", "-m", "crackerjack.tools.check_json"],
+        "format-json": ["uv", "run", "python", "-m", "crackerjack.tools.format_json"],
+        "check-jsonschema": [
+            "uv",
+            "run",
+            "python",
+            "-m",
+            "crackerjack.tools.check_jsonschema",
+        ],
+        "check-ast": ["uv", "run", "python", "-m", "crackerjack.tools.check_ast"],
         "check-added-large-files": [
             "uv",
             "run",
@@ -129,13 +141,36 @@ def _build_tool_commands(package_name: str) -> dict[str, list[str]]:
         "bandit": [
             "uv",
             "run",
-            "python",
-            "-m",
             "bandit",
-            "-c",
-            "pyproject.toml",
-            "-r",
-            package_name,
+            "-r",  # Recursive scanning
+            "--format",
+            "json",  # JSON output for structured parsing
+            "--severity-level",
+            "low",  # Detect all severity levels
+            "--confidence-level",
+            "low",  # Detect all confidence levels
+            "-x",
+            "tests",  # Exclude tests directory
+            f"./{package_name}",  # Target only the package directory
+        ],
+        "semgrep": [
+            "uvx",  # Use uvx for isolated semgrep environment
+            "--python=3.13",  # Explicitly use Python 3.13 for match/case syntax support
+            "semgrep",
+            "scan",
+            "--error",  # Exit with non-zero code when findings detected (CRITICAL security level)
+            "--json",  # JSON output for structured parsing
+            "--config",
+            "p/security-audit",  # Security-focused ruleset (comprehensive)
+            "--exclude",
+            ".pytest_cache",
+            "--exclude",
+            ".ruff_cache",
+            "--exclude",
+            "__pycache__",
+            "--exclude",
+            "tests",
+            f"./{package_name}",  # Target only the package directory
         ],
         "codespell": [
             "uv",
@@ -144,8 +179,25 @@ def _build_tool_commands(package_name: str) -> dict[str, list[str]]:
             "-m",
             "crackerjack.tools.codespell_wrapper",
         ],
-        "ruff-check": ["uv", "run", "python", "-m", "ruff", "check", "."],
-        "ruff-format": ["uv", "run", "python", "-m", "ruff", "format", "."],
+        "ruff-check": [
+            "uv",
+            "run",
+            "python",
+            "-m",
+            "ruff",
+            "check",
+            f"./{package_name}",
+        ],
+        "ruff-format": [
+            "uv",
+            "run",
+            "python",
+            "-m",
+            "ruff",
+            "format",
+            "--check",
+            f"./{package_name}",
+        ],
         # Mdformat in auto-fix mode for fast hooks (no --check)
         "mdformat": [
             "uv",
