@@ -63,7 +63,7 @@ class AsyncWorkflowPipeline:
     async def _execute_workflow_phases_async(self, options: OptionsProtocol) -> bool:
         success = True
 
-        self.phases.run_configuration_phase(options)
+        self.phases.run_configuration_phase(options)  # type: ignore[arg-type]
 
         if not await self._execute_cleaning_phase_async(options):
             success = False
@@ -76,12 +76,12 @@ class AsyncWorkflowPipeline:
 
             return False
 
-        if not self.phases.run_publishing_phase(options):
+        if not self.phases.run_publishing_phase(options):  # type: ignore[arg-type]
             success = False
             self.session.fail_task("workflow", "Publishing failed")
             return False
 
-        if not self.phases.run_commit_phase(options):
+        if not self.phases.run_commit_phase(options):  # type: ignore[arg-type]
             success = False
 
         return success
@@ -113,10 +113,10 @@ class AsyncWorkflowPipeline:
 
         result = await self.timeout_manager.with_timeout(
             "file_operations",
-            asyncio.to_thread(self.phases.run_cleaning_phase, options),
+            asyncio.to_thread(self.phases.run_cleaning_phase, options),  # type: ignore[arg-type]
             strategy=TimeoutStrategy.RETRY_WITH_BACKOFF,
         )
-        return bool(result)
+        return bool(result)  # type: ignore[return-value]
 
     async def _execute_quality_phase_async(self, options: OptionsProtocol) -> bool:
         if hasattr(options, "fast") and options.fast:
@@ -265,34 +265,34 @@ class AsyncWorkflowPipeline:
     async def _run_fast_hooks_async(self, options: OptionsProtocol) -> bool:
         result = await self.timeout_manager.with_timeout(
             "fast_hooks",
-            asyncio.to_thread(self.phases.run_fast_hooks_only, options),
+            asyncio.to_thread(self.phases.run_fast_hooks_only, options),  # type: ignore[arg-type]
             strategy=TimeoutStrategy.RETRY_WITH_BACKOFF,
         )
-        return bool(result)
+        return bool(result)  # type: ignore[return-value]
 
     async def _run_comprehensive_hooks_async(self, options: OptionsProtocol) -> bool:
         result = await self.timeout_manager.with_timeout(
             "comprehensive_hooks",
-            asyncio.to_thread(self.phases.run_comprehensive_hooks_only, options),
+            asyncio.to_thread(self.phases.run_comprehensive_hooks_only, options),  # type: ignore[arg-type]
             strategy=TimeoutStrategy.GRACEFUL_DEGRADATION,
         )
-        return bool(result)
+        return bool(result)  # type: ignore[return-value]
 
     async def _run_hooks_phase_async(self, options: OptionsProtocol) -> bool:
         result = await self.timeout_manager.with_timeout(
             "comprehensive_hooks",
-            asyncio.to_thread(self.phases.run_hooks_phase, options),
+            asyncio.to_thread(self.phases.run_hooks_phase, options),  # type: ignore[arg-type]
             strategy=TimeoutStrategy.GRACEFUL_DEGRADATION,
         )
-        return bool(result)
+        return bool(result)  # type: ignore[return-value]
 
     async def _run_testing_phase_async(self, options: OptionsProtocol) -> bool:
         result = await self.timeout_manager.with_timeout(
             "test_execution",
-            asyncio.to_thread(self.phases.run_testing_phase, options),
+            asyncio.to_thread(self.phases.run_testing_phase, options),  # type: ignore[arg-type]
             strategy=TimeoutStrategy.GRACEFUL_DEGRADATION,
         )
-        return bool(result)
+        return bool(result)  # type: ignore[return-value]
 
     async def _execute_ai_agent_workflow_async(
         self, options: OptionsProtocol, max_iterations: int = 10
@@ -301,7 +301,7 @@ class AsyncWorkflowPipeline:
             f"🤖 Starting AI Agent workflow (max {max_iterations} iterations)"
         )
 
-        self.phases.run_configuration_phase(options)
+        self.phases.run_configuration_phase(options)  # type: ignore[arg-type]
 
         if not await self._execute_cleaning_phase_async(options):
             self.session.fail_task("workflow", "Cleaning phase failed")
@@ -470,18 +470,18 @@ class AsyncWorkflowPipeline:
         )
 
     async def _run_final_workflow_phases(self, options: OptionsProtocol) -> bool:
-        if not self.phases.run_publishing_phase(options):
+        if not self.phases.run_publishing_phase(options):  # type: ignore[arg-type]
             self.session.fail_task("workflow", "Publishing failed")
             return False
 
-        if not self.phases.run_commit_phase(options):
+        if not self.phases.run_commit_phase(options):  # type: ignore[arg-type]
             self.session.fail_task("workflow", "Commit failed")
             return False
 
         return True
 
     async def _run_fast_hooks_with_retry_async(self, options: OptionsProtocol) -> bool:
-        return await asyncio.to_thread(self.phases.run_fast_hooks_only, options)
+        return await asyncio.to_thread(self.phases.run_fast_hooks_only, options)  # type: ignore[arg-type]
 
     async def _collect_test_issues_async(self, options: OptionsProtocol) -> list[str]:
         if not options.test:
@@ -510,7 +510,7 @@ class AsyncWorkflowPipeline:
         try:
             hook_results = await self.timeout_manager.with_timeout(
                 "comprehensive_hooks",
-                asyncio.to_thread(self.phases.hook_manager.run_comprehensive_hooks),
+                asyncio.to_thread(self.phases.hook_manager.run_comprehensive_hooks),  # type: ignore[arg-type]
                 strategy=TimeoutStrategy.GRACEFUL_DEGRADATION,
             )
 
@@ -616,6 +616,7 @@ class AsyncWorkflowOrchestrator:
         web_job_id: str | None = None,
         verbose: bool = False,
         debug: bool = False,
+        changed_only: bool = False,
     ) -> None:
         # Initialize console and pkg_path first
         self.console = console
@@ -624,6 +625,7 @@ class AsyncWorkflowOrchestrator:
         self.web_job_id = web_job_id
         self.verbose = verbose
         self.debug = debug
+        self.changed_only = changed_only
 
         # Configure ACB dependency injection using native patterns
         from acb.depends import depends
@@ -693,28 +695,36 @@ class AsyncWorkflowOrchestrator:
         return asyncio.run(self.run_complete_workflow_async(options))
 
     def run_cleaning_phase(self, options: OptionsProtocol) -> bool:
-        return self.phases.run_cleaning_phase(options)
+        result = self.phases.run_cleaning_phase(options)  # type: ignore[arg-type]
+        return bool(result)
 
     def run_fast_hooks_only(self, options: OptionsProtocol) -> bool:
-        return self.phases.run_fast_hooks_only(options)
+        result = self.phases.run_fast_hooks_only(options)  # type: ignore[arg-type]
+        return bool(result)
 
     def run_comprehensive_hooks_only(self, options: OptionsProtocol) -> bool:
-        return self.phases.run_comprehensive_hooks_only(options)
+        result = self.phases.run_comprehensive_hooks_only(options)  # type: ignore[arg-type]
+        return bool(result)
 
     def run_hooks_phase(self, options: OptionsProtocol) -> bool:
-        return self.phases.run_hooks_phase(options)
+        result = self.phases.run_hooks_phase(options)  # type: ignore[arg-type]
+        return bool(result)
 
     def run_testing_phase(self, options: OptionsProtocol) -> bool:
-        return self.phases.run_testing_phase(options)
+        result = self.phases.run_testing_phase(options)  # type: ignore[arg-type]
+        return bool(result)
 
     def run_publishing_phase(self, options: OptionsProtocol) -> bool:
-        return self.phases.run_publishing_phase(options)
+        result = self.phases.run_publishing_phase(options)  # type: ignore[arg-type]
+        return bool(result)
 
     def run_commit_phase(self, options: OptionsProtocol) -> bool:
-        return self.phases.run_commit_phase(options)
+        result = self.phases.run_commit_phase(options)  # type: ignore[arg-type]
+        return bool(result)
 
     def run_configuration_phase(self, options: OptionsProtocol) -> bool:
-        return self.phases.run_configuration_phase(options)
+        result = self.phases.run_configuration_phase(options)  # type: ignore[arg-type]
+        return bool(result)
 
     def _cleanup_resources(self) -> None:
         self.session.cleanup_resources()
