@@ -146,7 +146,7 @@ class DependencyResolver:
 
     def _build_constructor_kwargs(self, implementation: type) -> dict[str, Any]:
         init_sig = inspect.signature(implementation.__init__)
-        kwargs = {}
+        kwargs: dict[str, Any] = {}
 
         for param_name, param in init_sig.parameters.items():
             if param_name == "self":
@@ -467,7 +467,7 @@ class ServiceCollectionBuilder:
         # The decorator will inject all dependencies from the DI container
         self.container.register_transient(
             PublishManager,
-            factory=lambda: PublishManagerImpl(),
+            factory=PublishManagerImpl,
         )
 
         return self
@@ -513,7 +513,9 @@ class ServiceCollectionBuilder:
 
             filesystem = FileSystemService()
             git_service = GitService(console, pkg_path)
-            return InitializationService(console, filesystem, git_service, pkg_path)
+            service = InitializationService(console, filesystem, git_service, pkg_path)
+            # Cast to protocol type to ensure correct typing
+            return t.cast(InitializationServiceProtocol, service)
 
         self.container.register_transient(
             InitializationServiceProtocol,
