@@ -3,7 +3,7 @@ import time
 import typing as t
 from pathlib import Path
 
-from rich.console import Console
+from acb.console import Console
 
 
 class FileCache:
