@@ -12,7 +12,7 @@ from acb import console as acb_console
 from acb.console import Console
 
 from crackerjack.agents.coordinator import AgentCoordinator
-from crackerjack.services.acb_cache_adapter import CrackerjackCache
+from crackerjack.services.cache import CrackerjackCache
 
 logger = logging.getLogger(__name__)
 
@@ -123,7 +123,7 @@ class DualOutputGenerator:
     async def _generate_ai_reference(self) -> str:
         """Generate AI-REFERENCE.md with command decision trees and lookup tables."""
 
-        self.console.print("🤖 Generating AI reference documentation...")
+        self.console.print("🤖 Generating AI reference documentation")
 
         # Get current command structure
         from crackerjack.cli.options import CLI_OPTIONS
@@ -194,7 +194,7 @@ Generated by crackerjack documentation system v{self._get_version()}
     async def _generate_agent_capabilities(self) -> dict[str, t.Any]:
         """Generate AGENT-CAPABILITIES.json with structured agent data."""
 
-        self.console.print("🎯 Generating agent capabilities data...")
+        self.console.print("🎯 Generating agent capabilities data")
 
         # Initialize agent coordinator to get current agents
         from crackerjack.agents.base import AgentContext
@@ -248,7 +248,7 @@ Generated by crackerjack documentation system v{self._get_version()}
     async def _generate_error_patterns(self) -> dict[str, t.Any]:
         """Generate ERROR-PATTERNS.yaml with automated error resolution patterns."""
 
-        self.console.print("🔍 Generating error patterns documentation...")
+        self.console.print("🔍 Generating error patterns documentation")
 
         # Analyze existing error patterns and common fixes
         patterns = {
@@ -280,7 +280,7 @@ Generated by crackerjack documentation system v{self._get_version()}
     async def _generate_readme_enhancements(self) -> str:
         """Generate enhanced README.md sections with improved human readability."""
 
-        self.console.print("📖 Generating README enhancements...")
+        self.console.print("📖 Generating README enhancements")
 
         # Read current README if it exists
         if self.readme_path.exists():
@@ -693,7 +693,8 @@ graph TD
             return True
 
         # Check if source files are newer than generated docs
-        source_paths = list[t.Any](Path("crackerjack").rglob("*.py"))
+        # Use project_path to find source files instead of hardcoded "crackerjack"
+        source_paths = list[t.Any](self.project_path.rglob("*.py"))
         if not source_paths:
             return True
 
@@ -704,7 +705,7 @@ graph TD
             if p.exists()
         )
 
-        return latest_source > oldest_doc  # type: ignore[no-any-return]
+        return latest_source > oldest_doc
 
     async def _write_documentation_files(self, result: DocumentationResult) -> None:
         """Write generated documentation to files."""
