@@ -454,11 +454,16 @@ class IndividualHookExecutor:
                     parsed_output["errors"] + parsed_output["warnings"]
                 )
 
+                status = "passed" if result.returncode == 0 else "failed"
+                # Ensure failed hooks always have at least 1 issue count
+                issues_count = 1 if status == "failed" else 0
+
                 hook_result = HookResult(
                     id=hook.name,
                     name=hook.name,
-                    status="passed" if result.returncode == 0 else "failed",
+                    status=status,
                     duration=progress.duration or 0,
+                    issues_count=issues_count,
                 )
 
                 self._print_hook_summary(hook.name, hook_result, progress)
@@ -475,6 +480,7 @@ class IndividualHookExecutor:
                 name=hook.name,
                 status="failed",
                 duration=hook.timeout,
+                issues_count=1,  # Timeout counts as 1 issue
             )
         except Exception as e:
             progress.status = "failed"
@@ -486,6 +492,7 @@ class IndividualHookExecutor:
                 name=hook.name,
                 status="failed",
                 duration=progress.duration or 0,
+                issues_count=1,  # Error counts as 1 issue
             )
 
     async def _run_command_with_streaming(
@@ -515,14 +522,11 @@ class IndividualHookExecutor:
         return self._create_completed_process(cmd, process, stdout_lines, stderr_lines)
 
     async def _create_subprocess(self, cmd: list[str]) -> asyncio.subprocess.Process:
-        repo_root = (
-            self.pkg_path.parent
-            if self.pkg_path.name == "crackerjack"
-            else self.pkg_path
-        )
+        # Use pkg_path directly as the working directory for hook execution
+        # This ensures hooks run in the correct project directory regardless of project name
         return await asyncio.create_subprocess_exec(
             *cmd,
-            cwd=repo_root,
+            cwd=self.pkg_path,
             stdout=asyncio.subprocess.PIPE,
             stderr=asyncio.subprocess.PIPE,
         )
