@@ -41,6 +41,8 @@ class ProgressHookExecutor(HookExecutor):
         quiet: bool = False,
         show_progress: bool = True,
         debug: bool = False,
+        use_incremental: bool = False,
+        git_service: t.Any | None = None,
     ) -> None:
         """Initialize progress-enhanced hook executor.
 
@@ -51,8 +53,12 @@ class ProgressHookExecutor(HookExecutor):
             quiet: Suppress output
             show_progress: Enable progress bars (disable for CI/testing)
             debug: Enable debug output
+            use_incremental: Run hooks only on changed files
+            git_service: GitService instance for incremental execution
         """
-        super().__init__(console, pkg_path, verbose, quiet, debug)
+        super().__init__(
+            console, pkg_path, verbose, quiet, debug, use_incremental, git_service
+        )
         self.show_progress = show_progress and not quiet
         self.debug = debug
 
@@ -99,8 +105,10 @@ class ProgressHookExecutor(HookExecutor):
         total_duration = time.time() - start_time
         success = all(r.status == "passed" for r in results)
 
+        # Calculate performance gain for the summary
+        performance_gain = 0.0  # Default value for progress executor
         if not self.quiet:
-            self._print_summary(strategy, results, success)
+            self._print_summary(strategy, results, success, performance_gain)
 
         return HookExecutionResult(
             strategy_name=strategy.name,
@@ -242,6 +250,7 @@ class ProgressHookExecutor(HookExecutor):
                             status="error",
                             duration=0.0,
                             issues_found=[str(e)],
+                            issues_count=1,  # Error counts as 1 issue
                             stage=hook.stage.value,
                         )
                         results.append(error_result)
