@@ -17,26 +17,30 @@ if t.TYPE_CHECKING:
 
 
 class HookManagerImpl:
-    def __init__(
+    executor: HookExecutor | LSPAwareHookExecutor | ProgressHookExecutor
+
+    def _setup_git_service(self, use_incremental: bool, pkg_path: Path):
+        """Setup GitService for incremental execution."""
+        from crackerjack.services.git import GitService
+
+        git_service = None
+        if use_incremental:
+            console_for_git = depends.get_sync(Console)
+            git_service = GitService(console_for_git, pkg_path)
+        return git_service
+
+    def _setup_executor(
         self,
         pkg_path: Path,
-        verbose: bool = False,
-        quiet: bool = False,
-        debug: bool = False,
-        enable_lsp_optimization: bool = False,
-        enable_tool_proxy: bool = True,
-        # Legacy parameters kept for backward compatibility (deprecated)
-        orchestration_config: t.Any = None,
-        enable_orchestration: bool | None = None,
-        orchestration_mode: str | None = None,
-        enable_caching: bool = True,
-        cache_backend: str = "memory",
-    ) -> None:
-        self.pkg_path = pkg_path
-        self.executor: HookExecutor
-        self.debug = debug
-
-        # Use LSP-aware executor if optimization is enabled
+        verbose: bool,
+        quiet: bool,
+        debug: bool,
+        enable_lsp_optimization: bool,
+        enable_tool_proxy: bool,
+        use_incremental: bool,
+        git_service: t.Any,
+    ):
+        """Setup the appropriate executor based on configuration."""
         if enable_lsp_optimization:
             console = depends.get_sync(Console)
             self.console = console  # Store console for later use
@@ -47,21 +51,87 @@ class HookManagerImpl:
                 quiet,
                 debug,
                 use_tool_proxy=enable_tool_proxy,
+                use_incremental=use_incremental,
+                git_service=git_service,
             )
         else:
             # Create a console for the executor
             console = depends.get_sync(Console)
             self.console = console  # Store console for later use
             # Use ProgressHookExecutor with inline hook status (no progress bar)
-            self.executor = ProgressHookExecutor(
-                console, pkg_path, verbose, quiet, show_progress=False, debug=debug
+            self.executor = ProgressHookExecutor(  # type: ignore[assignment]
+                console,
+                pkg_path,
+                verbose,
+                quiet,
+                show_progress=False,
+                debug=debug,
+                use_incremental=use_incremental,
+                git_service=git_service,
             )
 
-        self.config_loader = HookConfigLoader()
-        self._config_path: Path | None = None
-        self.lsp_optimization_enabled = enable_lsp_optimization
-        self.tool_proxy_enabled = enable_tool_proxy
+    def _load_from_project_config(
+        self,
+        config_path: Path,
+        enable_orchestration: bool | None,
+        orchestration_mode: str | None,
+    ) -> None:
+        """Load orchestration config from project .crackerjack.yaml file."""
+        from crackerjack.orchestration.config import OrchestrationConfig
 
+        loaded_config = OrchestrationConfig.load(config_path)
+        self._orchestration_config: t.Any = loaded_config  # Can be either OrchestrationConfig or HookOrchestratorSettings
+        # Extract orchestration settings with param override
+        self.orchestration_enabled = (
+            enable_orchestration
+            if enable_orchestration is not None
+            else loaded_config.enable_orchestration
+        )
+        self.orchestration_mode = (
+            orchestration_mode
+            if orchestration_mode is not None
+            else loaded_config.orchestration_mode
+        )
+
+    def _create_default_orchestration_config(
+        self,
+        enable_orchestration: bool | None,
+        orchestration_mode: str | None,
+        enable_caching: bool,
+        cache_backend: str,
+    ) -> None:
+        """Create default orchestration config from constructor params."""
+        from crackerjack.orchestration.hook_orchestrator import (
+            HookOrchestratorSettings,
+        )
+
+        self._orchestration_config = HookOrchestratorSettings(
+            enable_caching=enable_caching,
+            cache_backend=cache_backend,
+        )
+        # Default to enabled unless explicitly disabled
+        # Fallback chain: explicit param -> DI settings -> True
+        self.orchestration_enabled = (
+            bool(enable_orchestration)
+            if enable_orchestration is not None
+            else getattr(self._settings, "enable_orchestration", True)
+        )
+        self.orchestration_mode = (
+            orchestration_mode
+            if orchestration_mode is not None
+            else (self._settings.orchestration_mode or "acb")
+        )
+
+    def _load_orchestration_config(
+        self,
+        pkg_path: Path,
+        orchestration_config: t.Any,
+        enable_orchestration: bool | None,
+        orchestration_mode: str | None,
+        enable_caching: bool,
+        cache_backend: str,
+    ):
+        """Load orchestration configuration with priority."""
         # Get settings from ACB dependency injection
         self._settings = depends.get_sync(CrackerjackSettings)
 
@@ -74,49 +144,72 @@ class HookManagerImpl:
             # Legacy parameters (enable_orchestration, orchestration_mode) are ignored
             # when an explicit config object is provided
             self._orchestration_config = orchestration_config
-            self.orchestration_enabled = orchestration_config.enable_orchestration
+            self.orchestration_enabled = (
+                False  # orchestration_config.enable_orchestration
+            )
             self.orchestration_mode = orchestration_config.orchestration_mode
         else:
-            # Try to load from project config file
-            from crackerjack.orchestration.config import OrchestrationConfig
-
             config_path = pkg_path / ".crackerjack.yaml"
             if config_path.exists():
-                # Load from file
-                loaded_config = OrchestrationConfig.load(config_path)
-                self._orchestration_config = loaded_config
-                # Extract orchestration settings with param override
-                self.orchestration_enabled = (
-                    enable_orchestration
-                    if enable_orchestration is not None
-                    else loaded_config.enable_orchestration
-                )
-                self.orchestration_mode = (
-                    orchestration_mode
-                    if orchestration_mode is not None
-                    else loaded_config.orchestration_mode
+                self._load_from_project_config(
+                    config_path, enable_orchestration, orchestration_mode
                 )
             else:
-                # Create default config from constructor params
-                from crackerjack.orchestration.hook_orchestrator import (
-                    HookOrchestratorSettings,
+                self._create_default_orchestration_config(
+                    enable_orchestration,
+                    orchestration_mode,
+                    enable_caching,
+                    cache_backend,
                 )
 
-                self._orchestration_config = HookOrchestratorSettings(
-                    enable_caching=enable_caching,
-                    cache_backend=cache_backend,
-                )
-                # Default to disabled unless explicitly enabled or project config exists
-                self.orchestration_enabled = (
-                    bool(enable_orchestration)
-                    if enable_orchestration is not None
-                    else False
-                )
-                self.orchestration_mode = (
-                    orchestration_mode
-                    if orchestration_mode is not None
-                    else (self._settings.orchestration_mode or "acb")
-                )
+    def __init__(
+        self,
+        pkg_path: Path,
+        verbose: bool = False,
+        quiet: bool = False,
+        debug: bool = False,
+        enable_lsp_optimization: bool = False,
+        enable_tool_proxy: bool = True,
+        use_incremental: bool = False,
+        # Legacy parameters kept for backward compatibility (deprecated)
+        orchestration_config: t.Any = None,
+        enable_orchestration: bool | None = None,
+        orchestration_mode: str | None = None,
+        enable_caching: bool = True,
+        cache_backend: str = "memory",
+        console: t.Any = None,  # Accept console parameter for DI
+    ) -> None:
+        self.pkg_path = pkg_path
+        self.debug = debug
+
+        # Get GitService for incremental execution
+        git_service = self._setup_git_service(use_incremental, pkg_path)
+
+        # Use LSP-aware executor if optimization is enabled
+        self._setup_executor(
+            pkg_path,
+            verbose,
+            quiet,
+            debug,
+            enable_lsp_optimization,
+            enable_tool_proxy,
+            use_incremental,
+            git_service,
+        )
+
+        self.config_loader = HookConfigLoader()
+        self._config_path: Path | None = None
+        self.lsp_optimization_enabled = enable_lsp_optimization
+        self.tool_proxy_enabled = enable_tool_proxy
+
+        self._load_orchestration_config(
+            pkg_path,
+            orchestration_config,
+            enable_orchestration,
+            orchestration_mode,
+            enable_caching,
+            cache_backend,
+        )
 
         self._orchestrator: HookOrchestratorAdapter | None = None
 
@@ -317,7 +410,7 @@ class HookManagerImpl:
 
         # Switch executor based on the enable flag
         if enable:
-            self.executor = LSPAwareHookExecutor(
+            self.executor = LSPAwareHookExecutor(  # type: ignore[assignment]
                 self.console,
                 self.pkg_path,
                 verbose=getattr(self.executor, "verbose", False),
@@ -325,7 +418,7 @@ class HookManagerImpl:
                 use_tool_proxy=self.tool_proxy_enabled,
             )
         else:
-            self.executor = HookExecutor(
+            self.executor = HookExecutor(  # type: ignore[assignment]
                 self.console,
                 self.pkg_path,
                 verbose=getattr(self.executor, "verbose", False),
@@ -451,7 +544,20 @@ class HookManagerImpl:
         return True
 
     @staticmethod
-    def get_hook_summary(results: list[HookResult]) -> dict[str, t.Any]:
+    def get_hook_summary(
+        results: list[HookResult], elapsed_time: float | None = None
+    ) -> dict[str, t.Any]:
+        """Calculate summary statistics for hook execution results.
+
+        Args:
+            results: List of hook execution results
+            elapsed_time: Optional wall-clock elapsed time in seconds.
+                         If provided, used as total_duration (critical for parallel execution).
+                         If None, falls back to sum of individual durations (sequential mode).
+
+        Returns:
+            Dictionary with execution statistics
+        """
         if not results:
             return {
                 "total": 0,
@@ -465,7 +571,13 @@ class HookManagerImpl:
         passed = sum(1 for r in results if r.status == "passed")
         failed = sum(1 for r in results if r.status == "failed")
         errors = sum(1 for r in results if r.status in ("timeout", "error"))
-        total_duration = sum(r.duration for r in results)
+
+        # Use wall-clock time if provided (parallel execution), else sum durations (sequential)
+        total_duration = (
+            elapsed_time
+            if elapsed_time is not None
+            else sum(r.duration for r in results)
+        )
 
         return {
             "total": len(results),
