@@ -3,6 +3,7 @@ import subprocess
 import threading
 import time
 import typing as t
+from contextlib import suppress
 from pathlib import Path
 
 from acb.console import Console
@@ -29,7 +30,9 @@ class TestExecutor:
             # the collection header appears in pytest output
             progress.update(total_tests=total_tests)
             # Set the collection status to indicate we pre-collected
-            progress.collection_status = f"Pre-collected {total_tests} tests, starting execution..."
+            progress.collection_status = (
+                f"Pre-collected {total_tests} tests, starting execution..."
+            )
 
         return self._execute_with_live_progress(cmd, timeout, progress=progress)
 
@@ -47,9 +50,13 @@ class TestExecutor:
             # the collection header appears in pytest output
             progress.update(total_tests=total_tests)
             # Set the collection status to indicate we pre-collected
-            progress.collection_status = f"Pre-collected {total_tests} tests, starting execution..."
+            progress.collection_status = (
+                f"Pre-collected {total_tests} tests, starting execution..."
+            )
 
-        return self._run_test_command_with_ai_progress(cmd, progress_callback, timeout, progress=progress)
+        return self._run_test_command_with_ai_progress(
+            cmd, progress_callback, timeout, progress=progress
+        )
 
     def _pre_collect_tests(self, original_cmd: list[str]) -> int:
         """
@@ -58,12 +65,22 @@ class TestExecutor:
         """
         # Create collection command by replacing the original command with the collect-only version
         # Preserve the test paths and other options, but replace the main pytest command
-        collect_cmd = ["uv", "run", "python", "-m", "pytest", "--collect-only", "-qq"]  # Use -qq to minimize output but still get collection info
+        collect_cmd = [
+            "uv",
+            "run",
+            "python",
+            "-m",
+            "pytest",
+            "--collect-only",
+            "-qq",
+        ]  # Use -qq to minimize output but still get collection info
 
         # Extract test paths and relevant options from original command
         test_path_found = False
         for i, arg in enumerate(original_cmd):
-            if not arg.startswith('-') and (arg.startswith("tests") or arg == "." or arg.endswith(".py")):
+            if not arg.startswith("-") and (
+                arg.startswith("tests") or arg == "." or arg.endswith(".py")
+            ):
                 # Add test paths to collection command
                 collect_cmd.extend(original_cmd[i:])
                 test_path_found = True
@@ -73,14 +90,14 @@ class TestExecutor:
         if not test_path_found:
             collect_cmd.append("tests" if (self.pkg_path / "tests").exists() else ".")
 
-        try:
+        with suppress(Exception):
             result = subprocess.run(
                 collect_cmd,
                 cwd=self.pkg_path,
                 capture_output=True,
                 text=True,
                 timeout=30,  # Collection should be fast
-                env=self._setup_test_environment()
+                env=self._setup_test_environment(),
             )
 
             # Parse output to extract number of collected tests
@@ -90,9 +107,6 @@ class TestExecutor:
                 match = re.search(r"collected\s+(\d+)\s+(?:item|test)s?", result.stdout)
                 if match:
                     return int(match.group(1))
-        except Exception as e:
-            # If collection fails, continue with normal execution
-            pass
 
         return 0  # Return 0 if collection fails
 
