@@ -143,6 +143,13 @@ class GitInterface(t.Protocol):
 
     def get_staged_files(self) -> list[str]: ...
 
+    def get_changed_files_by_extension(
+        self,
+        extensions: list[str],
+        include_staged: bool = True,
+        include_unstaged: bool = True,
+    ) -> list[Path]: ...
+
     def commit(self, message: str) -> bool: ...
 
     def push(self) -> bool: ...
@@ -157,6 +164,10 @@ class GitInterface(t.Protocol):
 
     def get_unpushed_commit_count(self) -> int: ...
 
+    def get_current_commit_hash(self) -> str | None: ...
+
+    def reset_hard(self, commit_hash: str) -> bool: ...
+
 
 @t.runtime_checkable
 class HookManager(t.Protocol):
@@ -349,9 +360,7 @@ class ConfigMergeServiceProtocol(ServiceProtocol, t.Protocol):
 class HookLockManagerProtocol(t.Protocol):
     def requires_lock(self, hook_name: str) -> bool: ...
 
-    async def acquire_hook_lock(
-        self, hook_name: str
-    ) -> t.AsyncContextManager[None]: ...
+    def acquire_hook_lock(self, hook_name: str) -> t.AsyncContextManager[None]: ...
 
     def get_lock_stats(self) -> dict[str, t.Any]: ...
 
@@ -859,7 +868,7 @@ class PerformanceCacheProtocol(t.Protocol):
 class QualityBaselineProtocol(t.Protocol):
     """Protocol for quality baseline tracking."""
 
-    def get_baseline(self) -> dict[str, t.Any]:
+    def get_current_baseline(self) -> dict[str, t.Any]:
         """Get current baseline metrics."""
         ...
 
@@ -951,6 +960,33 @@ class DebugServiceProtocol(ServiceProtocol, t.Protocol):
 
     def start_debug_session(self, session_id: str) -> None: ...
 
+    @property
+    def enabled(self) -> bool: ...
+
+    def log_workflow_phase(
+        self,
+        phase: str,
+        status: str,
+        details: dict[str, t.Any] | None = None,
+        duration: float | None = None,
+    ) -> None: ...
+
+    def set_workflow_success(self, success: bool) -> None: ...
+
+    def print_debug_summary(self) -> None: ...
+
+    def log_iteration_start(self, iteration_number: int) -> None: ...
+
+    def log_iteration_end(self, iteration_number: int, success: bool) -> None: ...
+
+    def log_test_failures(self, count: int) -> None: ...
+
+    def log_test_fixes(self, count: int) -> None: ...
+
+    def log_hook_failures(self, count: int) -> None: ...
+
+    def log_hook_fixes(self, count: int) -> None: ...
+
 
 @t.runtime_checkable
 class QualityIntelligenceProtocol(ServiceProtocol, t.Protocol):
