@@ -39,11 +39,20 @@ class HookResult:
     duration: float
     files_processed: int = 0
     issues_found: list[str] | None = None
+    issues_count: int = (
+        0  # Total count of issues (may exceed len(issues_found) if truncated)
+    )
     stage: str = "pre-commit"
+    exit_code: int | None = None  # Non-zero exit codes for failed hooks
+    error_message: str | None = None  # Error details from stderr or exceptions
+    is_timeout: bool = False  # Whether hook failed due to timeout
 
     def __post_init__(self) -> None:
         if self.issues_found is None:
             self.issues_found = []
+        # If issues_count not explicitly set, default to length of issues_found list
+        if self.issues_count == 0 and self.issues_found:
+            self.issues_count = len(self.issues_found)
 
 
 @dataclass
