@@ -642,15 +642,12 @@ class HookOrchestratorAdapter:
 
             start_time = time.time()
 
-            # ACB mode is plumbing validation only
-            if self.settings.execution_mode == "acb":
-                result = self._pass_result(hook, time.time() - start_time)
+            # Execute hooks via direct adapter calls or subprocess if no adapter exists
+            adapter = self._build_adapter(hook)
+            if adapter is not None:
+                result = await self._run_adapter(adapter, hook, start_time)
             else:
-                adapter = self._build_adapter(hook)
-                if adapter is not None:
-                    result = await self._run_adapter(adapter, hook, start_time)
-                else:
-                    result = self._run_subprocess(hook, start_time)
+                result = self._run_subprocess(hook, start_time)
 
             await self._maybe_cache(hook, result)
         except Exception as exc:
@@ -708,120 +705,366 @@ class HookOrchestratorAdapter:
             files_processed=0,
             issues_found=[],
             stage=hook.stage.value,
+            exit_code=None,  # No error for passed hooks
+            error_message=None,
+            is_timeout=False,
         )
 
     def _build_adapter(self, hook: HookDefinition) -> t.Any | None:
+        """Build adapter for hook, dispatching to specific adapter factories."""
         try:
-            if hook.name in ("ruff-check", "ruff-format"):
-                from crackerjack.adapters.format.ruff import RuffAdapter, RuffSettings
-
-                return RuffAdapter(
-                    settings=RuffSettings(
-                        mode="check" if "check" in hook.name else "format",
-                        fix_enabled=False,
-                    )
-                )
-            if hook.name == "bandit":
-                from crackerjack.adapters.security.bandit import BanditAdapter
-
-                return BanditAdapter()
-            if hook.name == "codespell":
-                from crackerjack.adapters.lint.codespell import CodespellAdapter
-
-                return CodespellAdapter()
-            if hook.name == "gitleaks":
-                from crackerjack.adapters.security.gitleaks import GitleaksAdapter
-
-                return GitleaksAdapter()
-            if hook.name in ("skylos", "zuban"):
-                from crackerjack.adapters.lsp.skylos import SkylosAdapter
-
-                if self.execution_context is None:
-                    # This is a critical error if we need the context for these adapters
-                    msg = f"Execution context required for {hook.name} adapter"
-                    raise ValueError(msg)
-                return SkylosAdapter(context=self.execution_context)
-            if hook.name == "complexipy":
-                from crackerjack.adapters.complexity.complexipy import ComplexipyAdapter
-
-                return ComplexipyAdapter()
-            if hook.name == "creosote":
-                from crackerjack.adapters.refactor.creosote import CreosoteAdapter
-
-                return CreosoteAdapter()
-            if hook.name in ("refurb", "pyrefly"):
-                from crackerjack.adapters.refactor.refurb import RefurbAdapter
-
-                return RefurbAdapter()
-            if hook.name == "mdformat":
-                from crackerjack.adapters.format.mdformat import MdformatAdapter
-
-                return MdformatAdapter()
+            adapter_factory = self._get_adapter_factory(hook.name)
+            if adapter_factory:
+                return adapter_factory(hook)
         except Exception:
             return None
         return None
 
+    def _get_adapter_factory(
+        self, hook_name: str
+    ) -> t.Callable[[HookDefinition], t.Any] | None:
+        """Get adapter factory function for hook name."""
+        factories = {
+            "ruff-check": self._build_ruff_adapter,
+            "ruff-format": self._build_ruff_adapter,
+            "bandit": self._build_bandit_adapter,
+            "codespell": self._build_codespell_adapter,
+            "gitleaks": self._build_gitleaks_adapter,
+            "skylos": self._build_skylos_adapter,
+            "zuban": self._build_zuban_adapter,
+            "complexipy": self._build_complexipy_adapter,
+            "creosote": self._build_creosote_adapter,
+            "refurb": self._build_refurb_adapter,
+            "pyrefly": self._build_refurb_adapter,
+            "mdformat": self._build_mdformat_adapter,
+        }
+        return factories.get(hook_name)
+
+    def _build_ruff_adapter(self, hook: HookDefinition) -> t.Any:
+        """Build Ruff adapter for format or check mode."""
+        from crackerjack.adapters.format.ruff import RuffAdapter, RuffSettings
+
+        is_format_mode = "format" in hook.name
+        is_check_mode = "check" in hook.name
+
+        return RuffAdapter(
+            settings=RuffSettings(
+                mode="format" if is_format_mode else "check",
+                fix_enabled=True,  # Enable fixing for both check and format modes
+                unsafe_fixes=is_check_mode,  # Enable unsafe fixes for check mode only
+            )
+        )
+
+    def _build_bandit_adapter(self, hook: HookDefinition) -> t.Any:
+        """Build Bandit security adapter."""
+        from crackerjack.adapters.security.bandit import BanditAdapter
+
+        return BanditAdapter()
+
+    def _build_codespell_adapter(self, hook: HookDefinition) -> t.Any:
+        """Build Codespell lint adapter."""
+        from crackerjack.adapters.lint.codespell import CodespellAdapter
+
+        return CodespellAdapter()
+
+    def _build_gitleaks_adapter(self, hook: HookDefinition) -> t.Any:
+        """Build Gitleaks security adapter."""
+        from crackerjack.adapters.security.gitleaks import GitleaksAdapter
+
+        return GitleaksAdapter()
+
+    def _build_skylos_adapter(self, hook: HookDefinition) -> t.Any:
+        """Build Skylos LSP adapter."""
+        from crackerjack.adapters.lsp.skylos import SkylosAdapter
+
+        if self.execution_context is None:
+            msg = f"Execution context required for {hook.name} adapter"
+            raise ValueError(msg)
+        return SkylosAdapter(context=self.execution_context)
+
+    def _build_zuban_adapter(self, hook: HookDefinition) -> t.Any:
+        """Build Zuban type checking adapter."""
+        from crackerjack.adapters.type.zuban import ZubanAdapter, ZubanSettings
+
+        return ZubanAdapter(settings=ZubanSettings())
+
+    def _build_complexipy_adapter(self, hook: HookDefinition) -> t.Any:
+        """Build Complexipy complexity adapter."""
+        from crackerjack.adapters.complexity.complexipy import ComplexipyAdapter
+
+        return ComplexipyAdapter()
+
+    def _build_creosote_adapter(self, hook: HookDefinition) -> t.Any:
+        """Build Creosote refactor adapter."""
+        from crackerjack.adapters.refactor.creosote import CreosoteAdapter
+
+        return CreosoteAdapter()
+
+    def _build_refurb_adapter(self, hook: HookDefinition) -> t.Any:
+        """Build Refurb refactor adapter."""
+        from crackerjack.adapters.refactor.refurb import RefurbAdapter
+
+        return RefurbAdapter()
+
+    def _build_mdformat_adapter(self, hook: HookDefinition) -> t.Any:
+        """Build Mdformat markdown adapter."""
+        from crackerjack.adapters.format.mdformat import MdformatAdapter
+
+        return MdformatAdapter()
+
+    def _get_reporting_tools(self) -> set[str]:
+        """Get the set of tools that report issues."""
+        return {"complexipy", "refurb", "gitleaks", "creosote"}
+
+    def _get_formatters(self) -> set[str]:
+        """Get the set of formatting tools."""
+        return {"ruff-format"}
+
+    def _determine_status(self, hook: HookDefinition, qa_result: t.Any) -> str:
+        """Determine the status based on hook name and QA result."""
+        reporting_tools = self._get_reporting_tools()
+        formatters = self._get_formatters()
+
+        # Override status for tools that found issues but returned SUCCESS/WARNING
+        if (
+            (hook.name in reporting_tools or hook.name in formatters)
+            and qa_result.issues_found > 0
+            and qa_result.status in (QAResultStatus.SUCCESS, QAResultStatus.WARNING)
+        ):
+            return "failed"  # Trigger auto-fix stage
+        return (
+            "passed"
+            if qa_result.status in (QAResultStatus.SUCCESS, QAResultStatus.WARNING)
+            else "failed"
+        )
+
+    def _build_issues_list(self, qa_result: t.Any) -> list[str]:
+        """Build the issues list from the QA result.
+
+        This method uses the adapter's pre-formatted details string directly
+        instead of re-parsing it, which preserves the original formatting and
+        prevents loss of detailed error information.
+
+        Args:
+            qa_result: QAResult from adapter execution
+
+        Returns:
+            List of issue strings for display. Returns empty list if no issues.
+        """
+        if qa_result.issues_found == 0:
+            return []
+
+        # NEW: Use adapter's pre-formatted details directly
+        if qa_result.details:
+            # Parse detail lines from the adapter's formatted output
+            detail_lines = [
+                line.strip()
+                for line in qa_result.details.split("\n")
+                if line.strip() and not line.strip().startswith("...")
+            ]
+
+            # If we successfully parsed details, use them
+            if detail_lines:
+                # Show first 20 issues, then add summary for remainder
+                max_displayed = 20
+                if len(detail_lines) > max_displayed:
+                    issues = detail_lines[:max_displayed]
+                    remaining = len(detail_lines) - max_displayed
+                    issues.append(
+                        f"... and {remaining} more issue{'s' if remaining != 1 else ''} "
+                        f"(run with --ai-debug for full details)"
+                    )
+                else:
+                    issues = detail_lines
+
+                # If qa_result reports more issues than we have details for, note it
+                if qa_result.issues_found > len(detail_lines):
+                    extra = qa_result.issues_found - len(detail_lines)
+                    issues.append(
+                        f"... and {extra} additional issue{'s' if extra != 1 else ''} without details"
+                    )
+
+                return issues
+
+        # Fallback: No details available or details parsing failed
+        # This should only happen when the adapter doesn't provide detailed output
+        count = qa_result.issues_found
+        return [
+            f"{count} issue{'s' if count != 1 else ''} found (run with --ai-debug for full details)"
+        ]
+
+    def _extract_error_details(
+        self, hook: HookDefinition, qa_result: t.Any, status: str, issues: list[str]
+    ) -> tuple[int | None, str | None, list[str]]:
+        """Extract error details for failed hooks from adapter results.
+
+        Note: This method should only add the generic fallback if _build_issues_list
+        hasn't already provided a fallback message. This prevents double-fallback.
+
+        Args:
+            hook: Hook definition
+            qa_result: QAResult from adapter execution
+            status: Hook status (passed/failed)
+            issues: Issues list from _build_issues_list
+
+        Returns:
+            Tuple of (exit_code, error_message, updated_issues)
+        """
+        exit_code = None
+        error_message = None
+
+        if status == "failed":
+            if hasattr(qa_result, "details") and qa_result.details:
+                # For adapter-based hooks, use details as error message
+                error_message = qa_result.details[:500]  # Truncate if very long
+
+                # Only extract error from details if issues list is truly empty
+                # (not just a fallback message from _build_issues_list)
+                if not issues:
+                    error_lines = [
+                        line.strip()
+                        for line in qa_result.details.split("\n")
+                        if line.strip()
+                    ][:10]
+                    issues = error_lines or ["Hook failed with no parseable output"]
+            elif not issues:
+                # Only add generic fallback if we have absolutely no information
+                # This should be rare since _build_issues_list provides a fallback
+                issues = [
+                    f"Hook {hook.name} failed with no detailed output (exit code: {qa_result.exit_code if hasattr(qa_result, 'exit_code') else 'unknown'})"
+                ]
+
+        return exit_code, error_message, issues
+
+    def _calculate_total_issues(
+        self, qa_result: t.Any, status: str, issues: list[str]
+    ) -> int:
+        """Calculate the total count of issues from qa_result.
+
+        This method distinguishes between:
+        1. Genuine code issues (show actual count)
+        2. Configuration/tool errors (show 0, not forced to 1)
+        3. Parsing failures (may show 1 if no issues parseable)
+
+        The key insight: QAResultStatus.ERROR indicates a config/tool error,
+        not a code quality issue. These should show 0 issues, not 1.
+        """
+        # Get the actual total count of issues from qa_result
+        # This may be larger than len(issues) if issues were truncated for display
+        total_issues = (
+            qa_result.issues_found
+            if hasattr(qa_result, "issues_found")
+            else len(issues)
+        )
+
+        # Only force "1 issue" for genuine parsing failures, not config errors
+        if status == "failed" and total_issues == 0:
+            # Check if this is a config/tool error vs code quality failure
+            if (
+                hasattr(qa_result, "status")
+                and qa_result.status == QAResultStatus.ERROR
+            ):
+                # Config/tool error - show actual count (0)
+                # This prevents misleading "1 issue" for things like:
+                # - Missing binary
+                # - Invalid configuration
+                # - Tool initialization failures
+                return 0
+            else:
+                # Parsing failure or unexpected error - show 1 to indicate problem
+                # This handles cases where the tool found issues but we couldn't parse them
+                return max(total_issues, 1)
+
+        return total_issues
+
+    def _create_success_result(
+        self, hook: HookDefinition, qa_result: t.Any, start_time: float
+    ) -> HookResult:
+        """Create a HookResult for successful execution."""
+        files_processed = (
+            len(qa_result.files_checked) if hasattr(qa_result, "files_checked") else 0
+        )
+        status = self._determine_status(hook, qa_result)
+        issues = self._build_issues_list(qa_result)
+
+        # Extract error details for failed hooks from adapter results
+        exit_code, error_message, issues = self._extract_error_details(
+            hook, qa_result, status, issues
+        )
+
+        # Calculate the total issues count
+        total_issues = self._calculate_total_issues(qa_result, status, issues)
+
+        return HookResult(
+            id=hook.name,
+            name=hook.name,
+            status=status,
+            duration=self._elapsed(start_time),
+            files_processed=files_processed,
+            issues_found=issues,
+            issues_count=total_issues,  # Store the actual total count
+            stage=hook.stage.value,
+            exit_code=exit_code,  # Adapters don't provide exit codes directly
+            error_message=error_message,
+            is_timeout=False,
+        )
+
+    def _create_timeout_result(
+        self, hook: HookDefinition, start_time: float
+    ) -> HookResult:
+        """Create a HookResult for timeout."""
+        duration = self._elapsed(start_time)
+        return HookResult(
+            id=hook.name,
+            name=hook.name,
+            status="timeout",
+            duration=duration,
+            files_processed=0,
+            issues_found=[f"Hook timed out after {hook.timeout}s"],
+            issues_count=1,  # Timeout counts as 1 issue
+            stage=hook.stage.value,
+            exit_code=124,  # Standard timeout exit code
+            error_message=f"Execution exceeded timeout of {hook.timeout}s",
+            is_timeout=True,
+        )
+
+    def _create_error_result(
+        self, hook: HookDefinition, start_time: float, error: Exception
+    ) -> HookResult:
+        """Create a HookResult for error."""
+        return HookResult(
+            id=hook.name,
+            name=hook.name,
+            status="error",
+            duration=self._elapsed(start_time),
+            files_processed=0,
+            issues_found=[f"Adapter execution error: {error}"],
+            issues_count=1,  # Error counts as 1 issue
+            stage=hook.stage.value,
+            exit_code=1,
+            error_message=str(error),
+            is_timeout=False,
+        )
+
     async def _run_adapter(
         self, adapter: t.Any, hook: HookDefinition, start_time: float
     ) -> HookResult:
         import asyncio
-        from pathlib import Path
 
         try:
             await adapter.init()
+            # Let the adapter determine the appropriate files to check
+            # Pass None to allow the adapter to scan for appropriate files
             qa_result = await asyncio.wait_for(
-                adapter.check(files=[Path()]), timeout=hook.timeout
-            )
-            files_processed = (
-                len(qa_result.files_checked)
-                if hasattr(qa_result, "files_checked")
-                else 0
-            )
-            status = (
-                "passed"
-                if qa_result.status in (QAResultStatus.SUCCESS, QAResultStatus.WARNING)
-                else "failed"
-            )
-            issues = [
-                str(error)
-                for error in (
-                    getattr(qa_result, "message", ""),
-                    getattr(qa_result, "details", ""),
-                )
-                if isinstance(error, str) and error.strip()
-            ]
-            return HookResult(
-                id=hook.name,
-                name=hook.name,
-                status=status,
-                duration=self._elapsed(start_time),
-                files_processed=files_processed,
-                issues_found=issues,
-                stage=hook.stage.value,
+                adapter.check(files=None), timeout=hook.timeout
             )
+            return self._create_success_result(hook, qa_result, start_time)
         except TimeoutError:
-            return HookResult(
-                id=hook.name,
-                name=hook.name,
-                status="timeout",
-                duration=self._elapsed(start_time),
-                files_processed=0,
-                issues_found=[f"Hook timed out after {hook.timeout}s"],
-                stage=hook.stage.value,
-            )
+            return self._create_timeout_result(hook, start_time)
         except Exception as e:
-            return HookResult(
-                id=hook.name,
-                name=hook.name,
-                status="error",
-                duration=self._elapsed(start_time),
-                files_processed=0,
-                issues_found=[f"Adapter execution error: {e}"],
-                stage=hook.stage.value,
-            )
+            return self._create_error_result(hook, start_time, e)
 
     def _run_subprocess(self, hook: HookDefinition, start_time: float) -> HookResult:
-        import re
         import subprocess
 
         cmd = hook.get_command()
@@ -830,19 +1073,24 @@ class HookOrchestratorAdapter:
         )
         output_text = (proc_result.stdout or "") + (proc_result.stderr or "")
 
-        files_processed = 0
-        for pattern in (
-            r"(\d+)\s+files?",
-            r"Checking\s+(\d+)\s+files?",
-            r"Found\s+(\d+)\s+files?",
-        ):
-            m = re.search(pattern, output_text, re.IGNORECASE)
-            if m:
-                files_processed = int(m.group(1))
-                break
+        files_processed = self._extract_file_count(output_text)
+        status = self._determine_hook_status(hook, proc_result, output_text)
+        issues = self._collect_issues(status, proc_result)
+
+        # Semgrep-specific JSON error parsing
+        if hook.name == "semgrep" and status == "failed":
+            issues = self._parse_semgrep_json_errors(output_text, issues)
+
+        # Extract error details for failed hooks
+        exit_code = proc_result.returncode if status == "failed" else None
+        error_message = None
+        if status == "failed" and output_text.strip():
+            # Capture stdout + stderr for failed hooks (truncate if very long)
+            error_message = output_text.strip()[:500]
+
+        # Ensure failed hooks always have at least 1 issue count
+        issues_count = max(len(issues), 1 if status == "failed" else 0)
 
-        status = "passed" if proc_result.returncode == 0 else "failed"
-        issues = [] if status == "passed" else [proc_result.stdout, proc_result.stderr]
         return HookResult(
             id=hook.name,
             name=hook.name,
@@ -850,9 +1098,163 @@ class HookOrchestratorAdapter:
             duration=self._elapsed(start_time),
             files_processed=files_processed,
             issues_found=issues,
+            issues_count=issues_count,
             stage=hook.stage.value,
+            exit_code=exit_code,
+            error_message=error_message,
+            is_timeout=False,
         )
 
+    def _extract_file_count(self, output_text: str) -> int:
+        """Extract file count from subprocess output using regex patterns."""
+        import re
+
+        file_count_patterns = [
+            r"(\d+)\s+files?\s+would\s+be",
+            r"(\d+)\s+files?\s+already\s+formatted",
+            r"(\d+)\s+files?\s+processed",
+            r"(\d+)\s+files?\s+checked",
+            r"(\d+)\s+files?\s+analyzed",
+            r"Checking\s+(\d+)\s+files?",
+            r"Found\s+(\d+)\s+files?",
+            r"(\d+)\s+files?",
+        ]
+
+        all_matches = []
+        for pattern in file_count_patterns:
+            matches = re.findall(pattern, output_text, re.IGNORECASE)
+            if matches:
+                all_matches.extend([int(m) for m in matches if m.isdigit()])
+
+        return max(all_matches) if all_matches else 0
+
+    def _determine_hook_status(
+        self, hook: HookDefinition, proc_result: t.Any, output_text: str
+    ) -> str:
+        """Determine hook status from subprocess return code and output."""
+        base_status = "passed" if proc_result.returncode == 0 else "failed"
+
+        if base_status == "passed":
+            return "passed"
+
+        # Check special cases where return code 1 indicates success
+        if self._is_formatting_success(hook, proc_result, output_text):
+            return "passed"
+
+        # For tools like ruff that return 1 when they detect issues but execute successfully
+        # These should still be considered "passed" execution-wise but may have issues found
+        if self._is_analysis_tool_success(hook, proc_result):
+            return "passed"
+
+        if self._is_bandit_success(hook, proc_result, output_text):
+            return "passed"
+
+        return "failed"
+
+    def _is_formatting_success(
+        self, hook: HookDefinition, proc_result: t.Any, output_text: str
+    ) -> bool:
+        """Check if formatting tool return code 1 indicates successful modification."""
+        if not hook.is_formatting or proc_result.returncode != 1:
+            return False
+        return "files were modified by this hook" in output_text.lower()
+
+    def _is_analysis_tool_success(
+        self, hook: HookDefinition, proc_result: t.Any
+    ) -> bool:
+        """Check if analysis tool return code 1 indicates findings (not failure)."""
+        if proc_result.returncode != 1:
+            return False
+        return hook.name in {
+            "creosote",
+            "complexipy",
+            "refurb",
+            "ruff-check",
+            "ruff-format",
+        }
+
+    def _is_bandit_success(
+        self, hook: HookDefinition, proc_result: t.Any, output_text: str
+    ) -> bool:
+        """Check if bandit return code 1 indicates findings (not failure)."""
+        if hook.name != "bandit" or proc_result.returncode != 1:
+            return False
+        output_text_lower = output_text.lower()
+        return (
+            "potential issues" in output_text_lower
+            or "no issues identified" not in output_text_lower
+        )
+
+    def _collect_issues(self, status: str, proc_result: t.Any) -> list[str]:
+        """Collect issues from subprocess output if hook failed.
+
+        For subprocess hooks (non-adapter), extracts error information from output.
+        Returns list of strings since the display layer handles both string and object types.
+        """
+        if status == "passed":
+            return []
+
+        # Get combined output
+        output_text = (proc_result.stdout or "") + (proc_result.stderr or "")
+        if not output_text.strip():
+            return [
+                f"Hook failed with exit code {getattr(proc_result, 'returncode', 'unknown')} and no output"
+            ]
+
+        # Try to extract meaningful error lines (first 10 non-empty lines)
+        error_lines = [
+            line.strip() for line in output_text.split("\n") if line.strip()
+        ][:10]
+
+        return error_lines or ["Hook failed with non-zero exit code"]
+
+    def _parse_semgrep_json_errors(
+        self, output_text: str, fallback_issues: list[str]
+    ) -> list[str]:
+        """Parse semgrep JSON output to extract errors from errors array.
+
+        Semgrep returns JSON with:
+        - "results": Security/code quality findings (usually empty when download fails)
+        - "errors": Configuration errors, download failures, etc.
+
+        Args:
+            output_text: Combined stdout + stderr from semgrep
+            fallback_issues: Issues collected from raw output (used if JSON parsing fails)
+
+        Returns:
+            List of formatted error strings
+        """
+        import json
+
+        try:
+            json_data = json.loads(output_text.strip())
+
+            issues = []
+
+            # Extract security findings from results array
+            if "results" in json_data:
+                for result in json_data.get("results", []):
+                    path = result.get("path", "unknown")
+                    line_num = result.get("start", {}).get("line", "?")
+                    rule_id = result.get("check_id", "unknown-rule")
+                    message = result.get("extra", {}).get(
+                        "message", "Security issue detected"
+                    )
+                    issues.append(f"{path}:{line_num} - {rule_id}: {message}")
+
+            # Extract errors (download failures, config errors, etc.)
+            if "errors" in json_data:
+                for error in json_data.get("errors", []):
+                    error_type = error.get("type", "SemgrepError")
+                    error_msg = error.get("message", str(error))
+                    issues.append(f"{error_type}: {error_msg}")
+
+            return issues or fallback_issues
+
+        except json.JSONDecodeError:
+            # JSON parsing failed, use fallback
+            return fallback_issues
+
     async def _maybe_cache(self, hook: HookDefinition, result: HookResult) -> None:
         if not (self.settings.enable_caching and self._cache_adapter):
             return
@@ -889,6 +1291,13 @@ class HookOrchestratorAdapter:
             name=hook.name,
             status="error",
             duration=0.0,
+            files_processed=0,
+            issues_found=[str(error)],
+            issues_count=1,  # Error counts as 1 issue
+            stage=hook.stage.value,
+            exit_code=1,
+            error_message=str(error),
+            is_timeout=False,
         )
 
     async def get_cache_stats(self) -> dict[str, t.Any]:
