@@ -6,7 +6,8 @@ from typing import Any, Self, TypedDict
 
 
 class CommandRunner[TReturn]:
-    def run_command(self, cmd: list[str], **kwargs: Any) -> TReturn: ...
+    def run_command(self, cmd: list[str], **kwargs: Any) -> TReturn:
+        raise NotImplementedError("Subclasses must implement run_command")
 
 
 class CommandResult(TypedDict):
@@ -86,7 +87,7 @@ def categorize_file(file_path: Path) -> str:
     path_str = str(file_path)
     name = file_path
     match path_str:
-        case s if name.suffix == ".py" and "/tests/" in s:
+        case s if name.suffix == ".py" and "/ tests /" in s:
             return "Python Test File"
         case s if name.suffix == ".py" and "__init__.py" in name.name:
             return "Python Module Init"
@@ -104,7 +105,7 @@ def categorize_file(file_path: Path) -> str:
     return "Unknown File Type"
 
 
-def process_hook_results[T, R](
+def process_hook_results[T: HookResult, R](
     results: list[T],
     success_handler: typing.Callable[[T], R],
     failure_handler: typing.Callable[[T], R],
@@ -112,9 +113,8 @@ def process_hook_results[T, R](
     processed_results: list[R] = []
     for result in results:
         if (
-            isinstance(result, dict)
-            and "status" in result
-            and result["status"] == HookStatus.SUCCESS
+            hasattr(result, "status")
+            and typing.cast(HookResult, result)["status"] == HookStatus.SUCCESS
         ):
             processed_results.append(success_handler(result))
         else:
