@@ -344,3 +344,79 @@ class GitService(GitInterface):
             if result.returncode == 0 and result.stdout.strip().isdigit():
                 return int(result.stdout.strip())
         return 0
+
+    def get_changed_files_by_extension(
+        self,
+        extensions: list[str],
+        include_staged: bool = True,
+        include_unstaged: bool = True,
+    ) -> list[Path]:
+        """Get changed files filtered by file extensions.
+
+        Args:
+            extensions: List of extensions to filter by (e.g., [".py", ".md"])
+            include_staged: Include staged files in results
+            include_unstaged: Include unstaged files in results
+
+        Returns:
+            List of Path objects for changed files matching the extensions
+
+        Example:
+            >>> git_service.get_changed_files_by_extension([".py"])
+            [Path("crackerjack/services/git.py"), Path("tests/test_git.py")]
+        """
+        try:
+            all_changed: set[str] = set()
+
+            if include_staged:
+                staged_result = self._run_git_command(GIT_COMMANDS["staged_files"])
+                if staged_result.stdout.strip():
+                    all_changed.update(staged_result.stdout.strip().split("\n"))
+
+            if include_unstaged:
+                unstaged_result = self._run_git_command(GIT_COMMANDS["unstaged_files"])
+                if unstaged_result.stdout.strip():
+                    all_changed.update(unstaged_result.stdout.strip().split("\n"))
+
+            # Filter by extensions
+            filtered = [
+                self.pkg_path / f
+                for f in all_changed
+                if f and any(f.endswith(ext) for ext in extensions)
+            ]
+
+            # Only return files that actually exist
+            return [f for f in filtered if f.exists()]
+
+        except Exception as e:
+            self.console.print(
+                f"[yellow]⚠️[/yellow] Error getting changed files by extension: {e}"
+            )
+            return []
+
+    def get_current_commit_hash(self) -> str | None:
+        """Get the hash of the current commit (HEAD)."""
+        try:
+            result = self._run_git_command(["rev-parse", "HEAD"])
+            if result.returncode == 0 and result.stdout.strip():
+                return result.stdout.strip()
+            return None
+        except Exception:
+            self.console.print("[red]❌[/red] Error getting current commit hash")
+            return None
+
+    def reset_hard(self, commit_hash: str) -> bool:
+        """Reset the repository to a specific commit hash (hard reset)."""
+        try:
+            result = self._run_git_command(["reset", "--hard", commit_hash])
+            if result.returncode == 0:
+                self.console.print(
+                    f"[green]✅[/green] Repository reset to {commit_hash[:8]}"
+                )
+                return True
+            else:
+                self.console.print(f"[red]❌[/red] Reset failed: {result.stderr}")
+                return False
+        except Exception as e:
+            self.console.print(f"[red]❌[/red] Error during reset: {e}")
+            return False
