@@ -1,6 +1,7 @@
 import json
 import sqlite3
 import threading
+import typing as t
 from contextlib import contextmanager
 from datetime import date, datetime
 from pathlib import Path
@@ -101,7 +102,7 @@ class MetricsCollector:
                     selected_strategy TEXT NOT NULL,
                     decision_reason TEXT, -- Why this strategy was chosen
                     context_data TEXT, -- JSON of execution context
-                    effectiveness_score REAL, -- How well the strategy worked (0-1)
+                    effectiveness_score REAL, -- How well the strategy worked (0 - 1)
                     FOREIGN KEY (job_id) REFERENCES jobs(job_id)
                 );
 
@@ -139,7 +140,7 @@ class MetricsCollector:
                     most_effective_strategy TEXT -- NEW
                 );
 
-                -- Create indexes for performance
+                --Create indexes for performance
                 CREATE INDEX IF NOT EXISTS idx_jobs_start_time ON jobs(start_time);
                 CREATE INDEX IF NOT EXISTS idx_errors_job_id ON errors(job_id);
                 CREATE INDEX IF NOT EXISTS idx_errors_type ON errors(error_type);
@@ -152,7 +153,7 @@ class MetricsCollector:
             """)
 
     @contextmanager
-    def _get_connection(self):
+    def _get_connection(self) -> t.Iterator[sqlite3.Connection]:
         conn = sqlite3.connect(str(self.db_path))
         conn.row_factory = sqlite3.Row
         try:
@@ -190,8 +191,8 @@ class MetricsCollector:
             conn.execute(
                 """
                     UPDATE jobs
-                    SET end_time = ?, status = ?, iterations = ?, error_message = ?
-                    WHERE job_id = ?
+                    SET end_time=?, status=?, iterations=?, error_message=?
+                    WHERE job_id=?
                 """,
                 (datetime.now(), status, iterations, error_message, job_id),
             )
@@ -394,7 +395,7 @@ class MetricsCollector:
                     AVG(
                         SELECT iteration_count
                         FROM orchestration_executions o
-                        WHERE o.job_id = sd.job_id
+                        WHERE o.job_id=sd.job_id
                     ) as avg_iterations_needed
                 FROM strategy_decisions sd
                 WHERE effectiveness_score IS NOT NULL
@@ -435,17 +436,25 @@ class MetricsCollector:
                     COUNT(*) as failure_count,
                     AVG(execution_time_ms) as avg_execution_time
                 FROM individual_test_executions
-                WHERE status = 'failed'
+                WHERE status='failed'
                 GROUP BY test_file, test_class, test_method
                 ORDER BY failure_count DESC
                 LIMIT 15
             """).fetchall()
 
             return {
-                "strategy_effectiveness": [dict(row) for row in strategy_stats],
-                "correlation_patterns": [dict(row) for row in correlation_patterns],
-                "performance_by_strategy": [dict(row) for row in performance_stats],
-                "test_failure_patterns": [dict(row) for row in test_failure_patterns],
+                "strategy_effectiveness": [
+                    dict[str, t.Any](row) for row in strategy_stats
+                ],
+                "correlation_patterns": [
+                    dict[str, t.Any](row) for row in correlation_patterns
+                ],
+                "performance_by_strategy": [
+                    dict[str, t.Any](row) for row in performance_stats
+                ],
+                "test_failure_patterns": [
+                    dict[str, t.Any](row) for row in test_failure_patterns
+                ],
             }
 
     def _update_daily_summary(
@@ -457,14 +466,14 @@ class MetricsCollector:
             """
             SELECT
                 COUNT(*) as total_jobs,
-                SUM(CASE WHEN status = 'success' THEN 1 ELSE 0 END) as successful_jobs,
-                SUM(CASE WHEN status = 'failed' THEN 1 ELSE 0 END) as failed_jobs,
+                SUM(CASE WHEN status='success' THEN 1 ELSE 0 END) as successful_jobs,
+                SUM(CASE WHEN status='failed' THEN 1 ELSE 0 END) as failed_jobs,
                 AVG(CASE
                     WHEN end_time IS NOT NULL
-                    THEN (julianday(end_time) - julianday(start_time)) * 86400000
+                    THEN (julianday(end_time)-julianday(start_time)) * 86400000
                     ELSE NULL
                 END) as avg_duration_ms,
-                SUM(CASE WHEN ai_agent = 1 AND status = 'success' THEN 1 ELSE 0 END) as ai_fixes
+                SUM(CASE WHEN ai_agent=1 AND status='success' THEN 1 ELSE 0 END) as ai_fixes
             FROM jobs
             WHERE DATE(start_time) = ?
         """,
@@ -475,10 +484,10 @@ class MetricsCollector:
             """
             SELECT
                 COUNT(*) as total_errors,
-                SUM(CASE WHEN error_type = 'hook' THEN 1 ELSE 0 END) as hook_errors,
-                SUM(CASE WHEN error_type = 'test' THEN 1 ELSE 0 END) as test_errors,
-                SUM(CASE WHEN error_type = 'lint' THEN 1 ELSE 0 END) as lint_errors,
-                SUM(CASE WHEN error_type = 'type_check' THEN 1 ELSE 0 END) as type_errors
+                SUM(CASE WHEN error_type='hook' THEN 1 ELSE 0 END) as hook_errors,
+                SUM(CASE WHEN error_type='test' THEN 1 ELSE 0 END) as test_errors,
+                SUM(CASE WHEN error_type='lint' THEN 1 ELSE 0 END) as lint_errors,
+                SUM(CASE WHEN error_type='type_check' THEN 1 ELSE 0 END) as type_errors
             FROM errors
             WHERE DATE(timestamp) = ?
         """,
@@ -534,9 +543,9 @@ class MetricsCollector:
             job_stats = conn.execute("""
                 SELECT
                     COUNT(*) as total_jobs,
-                    SUM(CASE WHEN status = 'success' THEN 1 ELSE 0 END) as successful_jobs,
-                    SUM(CASE WHEN status = 'failed' THEN 1 ELSE 0 END) as failed_jobs,
-                    SUM(CASE WHEN ai_agent = 1 THEN 1 ELSE 0 END) as ai_agent_jobs,
+                    SUM(CASE WHEN status='success' THEN 1 ELSE 0 END) as successful_jobs,
+                    SUM(CASE WHEN status='failed' THEN 1 ELSE 0 END) as failed_jobs,
+                    SUM(CASE WHEN ai_agent=1 THEN 1 ELSE 0 END) as ai_agent_jobs,
                     AVG(iterations) as avg_iterations
                 FROM jobs
             """).fetchone()
@@ -564,7 +573,7 @@ class MetricsCollector:
                 "error_breakdown": {
                     row["error_type"]: row["count"] for row in error_stats
                 },
-                "common_errors": [dict(row) for row in common_errors],
+                "common_errors": [dict[str, t.Any](row) for row in common_errors],
             }
 
 
