@@ -166,9 +166,8 @@ class TestOptionsObjectCreation:
             predictive_analytics=False,
             prediction_periods=10,
             analytics_dashboard=None,
-            enterprise_optimizer=False,
-            enterprise_profile=None,
-            enterprise_report=None,
+            advanced_profile=None,
+            advanced_report=None,
             mkdocs_integration=False,
             mkdocs_serve=False,
             mkdocs_theme="material",
@@ -249,9 +248,9 @@ class TestOptionsObjectCreation:
             predictive_analytics=False,
             prediction_periods=10,
             analytics_dashboard=None,
-            enterprise_optimizer=False,
-            enterprise_profile=None,
-            enterprise_report=None,
+            advanced_optimizer=False,
+            advanced_profile=None,
+            advanced_report=None,
             mkdocs_integration=False,
             mkdocs_serve=False,
             mkdocs_theme="material",
